@@ -5,12 +5,12 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib\Crypt\Base;
+use phpseclib3\Crypt\Common\BlockCipher;
 
 class Unit_Crypt_AES_OpenSSLTest extends Unit_Crypt_AES_TestCase
 {
     protected function setUp()
     {
-        $this->engine = Base::ENGINE_OPENSSL;
+        $this->engine = 'OpenSSL';
     }
 }
