@@ -7,17 +7,6 @@
 
 abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
 {
-    public static function setUpBeforeClass()
-    {
-        parent::setUpBeforeClass();
-        self::reRequireFile('Math/BigInteger.php');
-    }
-
-    public function getInstance($x = 0, $base = 10)
-    {
-        return new \phpseclib\Math\BigInteger($x, $base);
-    }
-
     public function testConstructorBase2()
     {
         // 2**65 = 36893488147419103232
@@ -37,6 +26,11 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $this->assertSame('18446744073709551616',    (string) $this->getInstance('0x10000000000000000', 16));
     }
 
+    public function testConstructorBase256()
+    {
+        $this->assertSame('-128',                        (string) $this->getInstance("\x80", -256));
+    }
+
     public function testToBytes()
     {
         $this->assertSame(chr(65), $this->getInstance('65')->toBytes());
@@ -55,6 +49,8 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
     public function testToBits()
     {
         $this->assertSame('1000001', $this->getInstance('65')->toBits());
+        $this->assertSame('10', $this->getInstance('-2')->toBits());
+        $this->assertSame('11111110', $this->getInstance('-2')->toBits(true));
     }
 
     public function testAdd()
@@ -219,6 +215,17 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $z = $this->getInstance('FFFFFFFFFFFFFFFFFFFFFFF', 16);
 
         $this->assertSame($z->toHex(), $x->bitwise_OR($y)->toHex());
+
+        $x = -0xFFFF;
+        $y = 2;
+        $z = $x ^ $y;
+
+        $x = $this->getInstance($x);
+        $y = $this->getInstance($y);
+        $z = $this->getInstance($z);
+
+        $this->assertSame($z->toString(), $x->bitwise_OR($y)->toString());
+        $this->assertSame($z->toString(), $y->bitwise_OR($x)->toString());
     }
 
     public function testBitwiseXOR()
@@ -234,12 +241,12 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $a = $this->getInstance(1);
         $b = $this->getInstance(-2);
         $c = $a->bitwise_xor($b);
-        $this->assertSame("$c", '3');
+        $this->assertSame("$c", '-1');
 
         $a = $this->getInstance('-6725760161961546982');
         $b = $this->getInstance(51);
         $c = $a->bitwise_xor($b);
-        $this->assertSame("$c", '6725760161961546965');
+        $this->assertSame("$c", '-6725760161961546967');
     }
 
     public function testBitwiseNOT()
@@ -304,42 +311,19 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $min = $this->getInstance(0);
         $max = $this->getInstance('18446744073709551616');
 
-        $rand1 = $min->random($min, $max);
+        $class = static::getStaticClass();
+        $rand1 = $class::randomRange($min, $max);
         // technically $rand1 can equal $min but with the $min and $max we've
         // chosen it's just not that likely
         $this->assertTrue($rand1->compare($min) > 0);
         $this->assertTrue($rand1->compare($max) < 0);
     }
 
-    public function testRandomOneArgument()
-    {
-        $min = $this->getInstance(0);
-        $max = $this->getInstance('18446744073709551616');
-
-        $rand1 = $min->random($max);
-        $this->assertTrue($rand1->compare($min) > 0);
-        $this->assertTrue($rand1->compare($max) < 0);
-
-        $rand2 = $max->random($min);
-        $this->assertTrue($rand2->compare($min) > 0);
-        $this->assertTrue($rand2->compare($max) < 0);
-
-        $this->assertFalse($rand1->equals($rand2));
-    }
-
     /**
      * @group github279
      */
     public function testDiffieHellmanKeyAgreement()
     {
-        if (getenv('TRAVIS') && PHP_VERSION === '5.3.3'
-            && MATH_BIGINTEGER_MODE === \phpseclib\Math\BigInteger::MODE_INTERNAL
-        ) {
-            $this->markTestIncomplete(
-                'This test hangs on PHP 5.3.3 using internal mode.'
-            );
-        }
-
         // "Oakley Group 14" 2048-bit modular exponentiation group as used in
         // SSH2 diffie-hellman-group14-sha1
         $prime = $this->getInstance(
@@ -360,10 +344,11 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
 
         /*
         Code for generation of $alicePrivate and $bobPrivate.
+        $class = static::getStaticClass();
         $one = $this->getInstance(1);
         $max = $one->bitwise_leftShift(512)->subtract($one);
-        $alicePrivate = $one->random($one, $max);
-        $bobPrivate = $one->random($one, $max);
+        $alicePrivate = $static::randomRange($one, $max);
+        $bobPrivate = $static::randomRange($one, $max);
         var_dump($alicePrivate->toHex(), $bobPrivate->toHex());
         */
 
@@ -400,7 +385,21 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $num = $this->getInstance(50);
         $str = print_r($num, true);
         $this->assertStringContainsString('[value] => 0x32', $str);
-        return $str;
+    }
+
+    public function testPrecision()
+    {
+        $a = $this->getInstance(51);
+        $this->assertSame($a->getPrecision(), -1);
+        $b = $a;
+        $c = clone $a;
+        $b->setPrecision(1);
+        $this->assertSame($a->getPrecision(), 1);
+        $this->assertSame("$a", '1');
+        $this->assertSame($b->getPrecision(), 1);
+        $this->assertSame("$b", '1');
+        $this->assertSame($c->getPrecision(), -1);
+        $this->assertSame("$c", '51');
     }
 
     /**
@@ -414,6 +413,61 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
         $x->powMod($e, $n);
     }
 
+    public function testRoot()
+    {
+        $bigInteger = $this->getInstance('64000000'); // (20^2)^3
+        $bigInteger = $bigInteger->root();
+        $this->assertSame('8000', (string) $bigInteger);
+        $bigInteger = $bigInteger->root(3);
+        $this->assertSame('20', (string) $bigInteger);
+    }
+
+    public function testPow()
+    {
+        $bigInteger = $this->getInstance('20');
+        $two = $this->getInstance('2');
+        $three = $this->getInstance('3');
+        $bigInteger = $bigInteger->pow($two);
+        $this->assertSame('400', (string) $bigInteger);
+        $bigInteger = $bigInteger->pow($three);
+        $this->assertSame('64000000', (string) $bigInteger); // (20^2)^3
+    }
+
+    public function testMax()
+    {
+        $class = static::getStaticClass();
+        $min = $this->getInstance('20');
+        $max = $this->getInstance('20000');
+        $this->assertSame((string) $max, (string) $class::max($min, $max));
+        $this->assertSame((string) $max, (string) $class::max($max, $min));
+    }
+
+    public function testMin()
+    {
+        $class = static::getStaticClass();
+        $min = $this->getInstance('20');
+        $max = $this->getInstance('20000');
+        $this->assertSame((string) $min, (string) $class::min($min, $max));
+        $this->assertSame((string) $min, (string) $class::min($max, $min));
+    }
+
+    public function testRandomPrime()
+    {
+        $class = static::getStaticClass();
+        $prime = $class::randomPrime(128);
+        $this->assertSame(128, $prime->getLength());
+    }
+
+    /**
+     * @group github1260
+     */
+    public function testZeros()
+    {
+        $a = $this->getInstance();
+        $b = $this->getInstance('00', 16);
+        $this->assertTrue($a->equals($b));
+    }
+
     /**
      * @group github1264
      */
@@ -448,27 +502,4 @@ abstract class Unit_Math_BigInteger_TestCase extends PhpseclibTestCase
             $this->assertSame(0, $x->compare($x2));
         }
     }
-
-    public function testHexWithNewLines()
-    {
-        $x = $this->getInstance('0xE932AC92252F585B3A80A4DD76A897C8B7652952FE788F6EC8DD640587A1EE5647670A8AD
-4C2BE0F9FA6E49C605ADF77B5174230AF7BD50E5D6D6D6D28CCF0A886A514CC72E51D209CC7
-72A52EF419F6A953F3135929588EBE9B351FCA61CED78F346FE00DBB6306E5C2A4C6DFC3779
-AF85AB417371CF34D8387B9B30AE46D7A5FF5A655B8D8455F1B94AE736989D60A6F2FD5CADB
-FFBD504C5A756A2E6BB5CECC13BCA7503F6DF8B52ACE5C410997E98809DB4DC30D943DE4E81
-2A47553DCE54844A78E36401D13F77DC650619FED88D8B3926E3D8E319C80C744779AC5D6AB
-E252896950917476ECE5E8FC27D5F053D6018D91B502C4787558A002B9283DA7', 16);
-
-        $y = $this->getInstance('0xE932AC92252F585B3A80A4DD76A897C8B7652952FE788F6EC8DD640587A1EE5647670A8AD', 16);
-        $this->assertSame("$x", "$y");
-    }
-
-    /**
-     * @group github2113
-     */
-    public function testPHP85ChrDeprecation()
-    {
-        $a = $this->getInstance('999999999');
-        $this->assertSame('3b9ac9ff', $a->toHex());
-    }
 }
